@@ -1,7 +1,4 @@
 import logging
-from py2neo import Node, Relationship, Subgraph
-from py2neo.ogm import GraphObject
-from py2neo.database import ClientError
 from uuid import uuid4
 
 from graphio.queries import nodes_create_unwind, nodes_merge_unwind
@@ -12,7 +9,7 @@ from graphio.objects.relationshipset import RelationshipSet
 log = logging.getLogger(__name__)
 
 
-class NodeSet(GraphObject):
+class NodeSet:
     """
     Container for a set of Nodes with the same labels and the same properties that define uniqueness.
     """
@@ -42,15 +39,12 @@ class NodeSet(GraphObject):
 
     def add_node(self, properties):
         """
-        Create a node in this NodeSet. If a Node subclass is provided,
-        the function create an instance of the subclass.
+        Create a node in this NodeSet.
 
         :param properties: Node properties.
         :type properties: dict
         """
-        n = Node(*self.labels, **properties)
-
-        self.nodes.append(n)
+        self.nodes.append(properties)
 
     def add_nodes(self, list_of_properties):
         for properties in list_of_properties:
@@ -77,12 +71,27 @@ class NodeSet(GraphObject):
         # add node if not found
         self.add_node(properties)
 
-    def to_dict(self):
+    def item_iterator(self):
         """
-        Create dictionary defining each node.
+        Generator function that yields the node properties for all nodes in this NodeSet.
+
+        This is used to create chunks of the nodes without iterating all nodes. This can be removes in future
+        when NodeSet and RelationshipSet fully support generators (instead of lists of nodes/relationships).
         """
         for node in self.nodes:
-            yield dict(node)
+            yield node
+
+    def to_dict(self):
+        """
+        Create dictionary defining the nodeset.
+        """
+        return {"labels":self.labels,"merge_keys":self.merge_keys,"nodes":self.nodes}
+
+    @classmethod
+    def from_dict(cls,nodeset_dict,batch_size=None):
+        ns = cls(labels=nodeset_dict["labels"],merge_keys=nodeset_dict["merge_keys"])
+        ns.add_nodes(nodeset_dict["nodes"])
+        return ns
 
     def create(self, graph, batch_size=None):
         """
@@ -95,12 +104,17 @@ class NodeSet(GraphObject):
 
         i = 1
         for batch in chunks(self.nodes, size=batch_size):
-            batch = Subgraph(list(batch))
+            batch = list(batch)
             log.debug('Batch {}'.format(i))
 
-            graph.create(batch)
+            query = nodes_create_unwind(self.labels)
+            log.debug(query)
+
+            result = graph.run(query, props=batch)
+
             i += 1
 
+    # TODO remove py2neo Node here, the node is just a dict now
     def filter_nodes(self, filter_func):
         """
         Filter node properties with a filter function, remove nodes that do not match from main list.
@@ -117,6 +131,7 @@ class NodeSet(GraphObject):
         self.nodes = filtered_nodes
         self.discarded_nodes = discarded_nodes
 
+    # TODO remove py2neo Node here, the node is just a dict now
     def reduce_node_properties(self, *keep_props):
         filtered_nodes = []
         for n in self.nodes:
@@ -153,6 +168,7 @@ class NodeSet(GraphObject):
             batch = list(batch)
             log.debug('Batch {}'.format(i))
             log.debug(batch[0])
+
             graph.run(query, props=batch)
             i += 1
 
