@@ -1,8 +1,6 @@
 from uuid import uuid4
 import logging
 import json
-from py2neo.ogm import GraphObject
-from py2neo.database import ClientError
 
 from graphio.objects.relationship import Relationship
 from graphio import defaults
@@ -13,7 +11,7 @@ from graphio.objects.helper import chunks, create_single_index, create_composite
 log = logging.getLogger(__name__)
 
 
-class RelationshipSet(GraphObject):
+class RelationshipSet:
     """
     Container for a set of Relationships with the same type of start and end nodes.
     """
@@ -81,10 +79,37 @@ class RelationshipSet(GraphObject):
                                end_node_properties, properties)
             self.relationships.append(rel)
 
-    def to_dict(self):
+    def item_iterator(self):
+        """
+        Generator function that yields the to_dict function for all relationships in this RelationshipSet.
+
+        This is used to create chunks of the relationships without iterating all relationships. This can be removes in future
+        when NodeSet and RelationshipSet fully support generators (instead of lists of nodes/relationships).
+        """
         for rel in self.relationships:
             yield rel.to_dict()
 
+    def to_dict(self):
+        return {"rel_type":self.rel_type,
+                "start_node_labels":self.start_node_labels,
+                "end_node_labels":self.end_node_labels,
+                "start_node_properties":self.start_node_properties,
+                "end_node_properties":self.end_node_properties,
+                "unique":self.unique,
+                "relationships":[rel.to_dict() for rel in self.relationships]}
+
+    @classmethod  
+    def from_dict(cls,relationship_dict,batch_size=None):
+        rs = cls(rel_type=relationship_dict["rel_type"],
+            start_node_labels=relationship_dict["start_node_labels"],
+            end_node_labels=relationship_dict["end_node_labels"],
+            start_node_properties=relationship_dict["start_node_properties"],
+            end_node_properties=relationship_dict["end_node_properties"],
+            batch_size=batch_size)
+        rs.unique = relationship_dict["unique"]
+        [rs.add_relationship(start_node_properties=rel["start_node_properties"],end_node_properties=rel["end_node_properties"],properties=rel["properties"]) for rel in relationship_dict["relationships"]]
+        return rs
+
     def filter_relationships_target_node(self, filter_func):
         """
         Filter properties of target node with a filter function, remove relationships that do not match from main list.
@@ -147,6 +172,7 @@ class RelationshipSet(GraphObject):
             # get parameters
             query_parameters = params_create_rels_unwind_from_objects(batch)
             log.debug(json.dumps(query_parameters))
+
             graph.run(query, **query_parameters)
             i += 1
 
@@ -173,6 +199,7 @@ class RelationshipSet(GraphObject):
             # get parameters
             query_parameters = params_create_rels_unwind_from_objects(batch)
             log.debug(json.dumps(query_parameters))
+
             graph.run(query, **query_parameters)
             i += 1
 
